* Output options: all can be turned on/off by adding or removing the NO;
* page number, date, centering, or page breaks, page length and width;
  OPTIONS NOnumber NOdate NOcenter FormDlim=' ' PageSize=MAX LineSize=120;
* Eliminate SAS default titles and names of tables in output (TRACE ON to show);
  TITLE; ODS TRACE OFF; ODS LISTING; ODS HTML; ODS GRAPHICS OFF;

***********************************************************************************;
*******             BEGIN MANIPULATION FOR HOFFMAN CHAPTER 2 DATA           *******;
*******                  CHANGE "filesave" to your directory                *******;
***********************************************************************************;

* Defining global variable for file location to be replaced in code below;
* \\Client\ precedes path in Virtual Desktop outside H drive;
  %LET filesave= C:\Dropbox\21SP_PSQF6242\PSQF6242_Example5b;
* Using UIowa virtual desktop instead; 
  *%LET filesave= \\Client\C:\Dropbox\21SP_PSQF6242\PSQF6242_Example5a;
* Location for SAS files for these models (uses macro variable filesave);
  LIBNAME filesave "&filesave.";

* Import chapter 2 example data into work library as Example5b;
DATA work.Example5b; SET filesave.SAS_Chapter2;
* Center quantitative predictors;
  age85 = age - 85;
  grip9 = grip - 9;
* Create dummy-coded binary predictors for dementia groups;
  demNF=.; demNC=.; * Create two new empty variables;
  IF demgroup=1 THEN DO; demNF=0; demNC=0; END; * Replace each for none group;
  IF demgroup=2 THEN DO; demNF=1; demNC=0; END; * Replace each for future group;
  IF demgroup=3 THEN DO; demNF=0; demNC=1; END; * Replace each for current group;
* Label new variables  note semi-colon is only at the end of ALL labels;
  LABEL   
  age85=     "age85: Age in Years (0=85)"
  grip9=     "grip9: Grip Strength in Pounds (0=9)"
  sexMW=     "sexMW: Sex (0=M, 1=W)"
  demNF=     "demNF: Dementia Contrast for None=0 vs Future=1"
  demNC=     "demNC: Dementia Contrast for None=0 vs Current=1"
  cognition= "cognition: Cognition Outcome"
  demgroup=  "demgroup: Dementia Group 1N 2F 3C";
* Select cases complete on variables;
  IF NMISS(cognition,age,grip,sexmw,demgroup)>0 THEN DELETE;
RUN;

* Open output directory to save results to;
ODS RTF FILE="&filesave.\Example5b_SAS_Output.rtf" 
        STYLE=HTMLBlue STARTPAGE=NO BODYTITLE;

***********************************************************************************;
*******                       BEGIN DESCRIPTIVE STATISTICS                  *******;
***********************************************************************************;

TITLE "SAS Descriptive Statistics";
PROC MEANS NOLABELS NONOBS NDEC=3 MEAN STDDEV VAR MIN MAX DATA=work.Example5b; 
     VAR cognition age grip sexMW; 
RUN;
PROC FREQ DATA=work.Example5b;
     TABLE sexMW*demgroup / NOROW NOCOL;
RUN; TITLE;

TITLE "SAS Histograms of Quantitative Variables";
PROC UNIVARIATE NOPRINT DATA=work.Example5b;
     VAR cognition age grip; 
     HISTOGRAM age / MIDPOINTS=80 TO 97 BY 1; 
     HISTOGRAM grip / MIDPOINTS=0 TO 19 BY 1; 
     HISTOGRAM cognition / MIDPOINTS=0 TO 45 BY 5; 
RUN; QUIT; TITLE;

TITLE "SAS Bivariate Correlations (OUT saves corrs to dataset)";
PROC CORR NOSIMPLE DATA=work.Example5b OUT=work.Corrs;
     VAR cognition age grip sexMW; 
RUN; TITLE;

***********************************************************************************;
*******                    BEGIN GENERAL LINEAR MODELS                      *******;
***********************************************************************************;

TITLE "SAS Empty Model Predicting Cognition";
PROC GLM DATA=work.Example5b NAMELEN=100;
     MODEL cognition = / ALPHA=.05 CLPARM SOLUTION SS3 EFFECTSIZE;
RUN; QUIT; TITLE;

TITLE "SAS Linear Age (0=85) Predicting Cognition";
PROC GLM DATA=work.Example5b NAMELEN=100;
     MODEL cognition = age85 / ALPHA=.05 CLPARM SOLUTION SS3 EFFECTSIZE;
     ODS OUTPUT ParameterEstimates=AgeLinEstimates; * Save for computing effect sizes;
RUN; QUIT; TITLE;
* Compute Cohen d effect size and r effect sizes from saved solution;
DATA work.AgeLinEstimates; SET work.AgeLinEstimates; %LET df=548;
     WHERE INDEX(Parameter,"Intercept")=0; * Do not print intercept;
     CohenD=(2*tvalue)/SQRT(&df.);
     EffectR=tvalue/SQRT((tvalue*tvalue)+&df.); 
RUN;
* Print effect size;
TITLE "Effect Size for Linear Age";
PROC PRINT NOOBS DATA=work.AgeLinEstimates; 
     VAR Parameter Estimate StdErr probt CohenD EffectR; 
RUN; TITLE;


TITLE "SAS Quadratic Age (0=85) Predicting Cognition";
PROC GLM DATA=work.Example5b NAMELEN=100;
     MODEL cognition = age85 age85*age85 / ALPHA=.05 CLPARM SOLUTION SS3 EFFECTSIZE;
     ODS OUTPUT ParameterEstimates=AgeQuadEstimates; * Save for computing effect sizes;
RUN; QUIT; TITLE;
* Compute Cohen d effect size and r effect sizes from saved solution;
DATA work.AgeQuadEstimates; SET work.AgeQuadEstimates; %LET df=547;
     WHERE INDEX(Parameter,"Intercept")=0; * Do not print intercept;
     CohenD=(2*tvalue)/SQRT(&df.);
     EffectR=tvalue/SQRT((tvalue*tvalue)+&df.); 
RUN;
* Print effect sizes;
TITLE "Effect Sizes for Linear and Quadratic Age";
PROC PRINT NOOBS DATA=work.AgeEstimates; 
     VAR Parameter Estimate StdErr probt CohenD EffectR; 
RUN; TITLE;


TITLE "SAS Linear Grip (0=9) Predicting Cognition";
PROC GLM DATA=work.Example5b NAMELEN=100;
     MODEL cognition = grip9 / ALPHA=.05 CLPARM SOLUTION SS3 EFFECTSIZE;
     ODS OUTPUT ParameterEstimates=GripLinEstimates; * Save for computing effect sizes;
RUN; QUIT; TITLE;
* Compute Cohen d effect size and r effect sizes;
DATA work.GripLinEstimates; SET work.GripLinEstimates; %LET df=548;
     CohenD=(2*tvalue)/SQRT(&df.); 
     EffectR=tvalue/SQRT((tvalue*tvalue)+&df.); 
RUN;
* Print effect size;
TITLE "Effect Size for Linear Grip";
PROC PRINT NOOBS DATA=work.GripLinEstimates; 
     WHERE INDEX(Parameter,"Intercept")=0; * Do not print intercept;
     VAR Parameter Estimate StdErr probt CohenD EffectR; 
RUN; TITLE;


TITLE "SAS Quadratic Grip (0=9) Predicting Cognition";
PROC GLM DATA=work.Example5b NAMELEN=100;
     MODEL cognition = grip9 grip9*grip9 / ALPHA=.05 CLPARM SOLUTION SS3 EFFECTSIZE;
     ODS OUTPUT ParameterEstimates=GripQuadEstimates; * Save for computing effect sizes;
RUN; QUIT; TITLE;
* Compute Cohen d effect size and r effect sizes;
DATA work.GripQuadEstimates; SET work.GripQuadEstimates; %LET df=547;
     CohenD=(2*tvalue)/SQRT(&df.); 
     EffectR=tvalue/SQRT((tvalue*tvalue)+&df.); 
RUN;
* Print effect sizes;
TITLE "Effect Sizes for Linear and Quadratic Grip";
PROC PRINT NOOBS DATA=work.GripQuadEstimates; 
     WHERE INDEX(Parameter,"Intercept")=0; * Do not print intercept;
     VAR Parameter Estimate StdErr probt CohenD EffectR; 
RUN; TITLE;


TITLE "SAS Sex (M=0, W=1) Predicting Cognition";
PROC GLM DATA=work.Example5b NAMELEN=100;
     MODEL cognition = sexMW / ALPHA=.05 CLPARM SOLUTION SS3 EFFECTSIZE;
     ESTIMATE "Cognition Mean for Men"   intercept 1 sexMW 0; * B0;
     ESTIMATE "Cognition Mean for Women" intercept 1 sexMW 1; * B0+B1;
     ESTIMATE "Mean Diff: Men vs. Women"             sexMW 1; * B1;
     ODS OUTPUT Estimates=SexEstimates; * Save for computing effect sizes;
RUN; QUIT; TITLE;
* Compute Cohen d effect size and r effect sizes from saved solution;
DATA work.SexEstimates; SET work.SexEstimates; %LET df=548;
     CohenD=(2*tvalue)/SQRT(&df.); 
     EffectR=tvalue/SQRT((tvalue*tvalue)+&df.); 
RUN;
TITLE "Effect Sizes for 2-Category Gender Group";
PROC PRINT NOOBS DATA=work.SexEstimates; 
     WHERE INDEX(Parameter,"Cognition")=0; * Do not print intercepts;
     VAR Parameter Estimate StdErr probt CohenD EffectR; 
RUN; TITLE;


TITLE "SAS Dementia Group (Ref=None) Predicting Cognition";
PROC GLM DATA=work.Example5b NAMELEN=100;
     MODEL cognition = demNF demNC / ALPHA=.05 CLPARM SOLUTION SS3 EFFECTSIZE;
     CONTRAST "Fut vs Cur" demNF -1 demNC  1; * Demo to get SS for linear combination;
     ESTIMATE "Cognition Mean for None"     intercept 1 demNF  0 demNC  0; * B0;
     ESTIMATE "Cognition Mean for Future"   intercept 1 demNF  1 demNC  0; * B0+B1;
     ESTIMATE "Cognition Mean for Current"  intercept 1 demNF  0 demNC  1; * B0+B2;
     ESTIMATE "Mean Diff: None vs. Future"              demNF  1 demNC  0; * B1;
     ESTIMATE "Mean Diff: None vs. Current"             demNF  0 demNC  1; * B2;
     ESTIMATE "Mean Diff: Future vs. Current"           demNF -1 demNC  1; * B2-B1;
     ODS OUTPUT Estimates=DemEstimates; * Save for computing effect sizes;
RUN; QUIT; TITLE;
* Compute Cohen d effect size and r effect sizes from saved solution;
DATA work.DemEstimates; SET work.DemEstimates; %LET df=547;
     CohenD=(2*tvalue)/SQRT(&df.); * Number = DF denominator; 
     EffectR=tvalue/SQRT((tvalue*tvalue)+&df.); 
RUN;
* Print effect sizes;
TITLE "Effect Sizes for 3-Category Dementia Status";
PROC PRINT NOOBS DATA=work.DemEstimates; 
     WHERE INDEX(Parameter,"Cognition")=0; * Do not print intercepts;
     VAR Parameter Estimate StdErr probt CohenD EffectR; 
RUN; TITLE;


TITLE "SAS Combined Final Model Predicting Cognition";
PROC GLM DATA=work.Example5b NAMELEN=100;
     MODEL cognition = age85 grip9 sexMW demNF demNC / ALPHA=.05 CLPARM SOLUTION SS3 EFFECTSIZE;
     CONTRAST "F-Test DFnum=5 for Model (demo)" age85 1, grip9 1, sexMW 1, demNF 1, demNC 1;
     CONTRAST "F-Test DFnum=2 for Demgroup"      demNF  1, demNC  1; * For overall group;
     CONTRAST "F-Test DFnum=2 for Age and Sex"   age85  1, sexMW  1; * For demographic vars;
     ESTIMATE "Mean Diff: None vs. Future"       demNF  1  demNC  0; * B4;
     ESTIMATE "Mean Diff: None vs. Current"      demNF  0  demNC  1; * B5;
     ESTIMATE "Mean Diff: Future vs. Current"    demNF -1  demNC  1; * B5-B4;
     ODS OUTPUT ParameterEstimates=ModelEstimates Estimates=ReqEstimates; 
RUN; QUIT; TITLE; * Save for computing effect sizes;
* Compute Cohen d effect size and r effect sizes;
DATA work.FinalEstimates; LENGTH Parameter $50; 
     SET work.ModelEstimates ReqEstimates; %LET df=544;
     CohenD=(2*tvalue)/SQRT(&df.); 
     EffectR=tvalue/SQRT((tvalue*tvalue)+&df.); 
RUN;
* Print effect sizes;
TITLE "Effect Sizes for Final Model";
PROC PRINT NOOBS DATA=work.FinalEstimates; 
     * Do not print intercept or redundant info;
     WHERE INDEX(Parameter,"Intercept")=0 AND INDEX(Parameter,"dem")=0; 
     VAR Parameter Estimate StdErr probt CohenD EffectR; 
RUN; TITLE;


TITLE "SAS Combined Model Predicting Cognition: Get Std Slopes";
PROC REG DATA=work.Example5b;
     MODEL cognition = age grip sexMW demNF demNC / ALPHA=.05 STB;
     * Would have to recode dem contrasts to get demFC std slope;
RUN; QUIT; TITLE;

* SAS: Make a copy of variables to z-score for demonstration of standardized slopes;
DATA work.Example5b; SET work.Example5b;
  cognitionz=cognition; agez=age; gripz=grip;
  sexMWz=sexMW; demNFz=demNF; demNCz=demNC;
RUN;
* SAS: Z-score variables for demonstration of standardized slopes;
PROC STANDARD DATA= work.Example5b MEAN=0 STD=1 OUT= work.Example5b;
     VAR cognitionz agez gripz sexMWz demNFz demNCz; 
RUN;
TITLE "SAS Combined Model Predicting Cognition: Z-Score version";
PROC GLM DATA=work.Example5b NAMELEN=100;
     MODEL cognitionz = agez gripz sexMWz demNFz demNCz / ALPHA=.05 CLPARM SOLUTION SS3 EFFECTSIZE;
     ESTIMATE "Mean Diff: Future vs. Current"   demNFz -1 demNCz  1; * B5-B4;
RUN; QUIT; TITLE;

* Close output;
ODS RTF CLOSE;

