// Prevent "more" messages from appearing
   set more off
// Control line length
   set linesize 150

********************************************************************************
******                  BEGIN IMPORT FOR CHAPTER 2 DATA                  *******
******                CHANGE "filesave" to your directory                *******
********************************************************************************

// Defining global variable for file location to be replaced in code below
// \\Client\ precedes path in Virtual Desktop outside H drive
    global filesave "C:\Dropbox\21SP_PSQF6242\PSQF6242_Example5b"

// Import chapter 2 data into temporary file and center predictors
   use "$filesave\STATA_Chapter2.dta", clear // Has converted all variables to lower-case
   
// Save results to separate file
   log using $filesave\Example5b_STATA_Output.log, replace

// Center quantitative predictors
   gen age85 = age - 85
   gen grip9 = grip - 9
// Create dummy-coded binary predictors for dementia groups
   gen demnf=.  // Create two new empty variables 
   gen demnc=.
// Replace for demgroup = none   
   replace demnf=0 if demgroup==1
   replace demnc=0 if demgroup==1
// Replace for demgroup = future 
   replace demnf=1 if demgroup==2
   replace demnc=0 if demgroup==2
// Replace for demgroup = current
   replace demnf=0 if demgroup==3
   replace demnc=1 if demgroup==3
// Label all variables
   label variable age85     "age85: Age in Years (0=85)"
   label variable grip9     "grip9: Grip Strength in Pounds (0=9)"
   label variable sexmw     "sexmw: Sex (0=Men, 1=Women)"
   label variable demnf     "demnf: Dementia Contrast for None=0 vs Future=1"
   label variable demnc     "demnc: Dementia Contrast for None=0 vs Current=1"
   label variable cognition "cognition: Cognition Outcome"
   label variable demgroup  "demgroup: Dementia Group 1N 2F 3C"
// Select cases complete on variables
   egen nmiss=rowmiss(cognition age grip sexmw demgroup)
   drop if nmiss>0

    
********************************************************************************
*******                   BEGIN DESCRIPTIVE STATISTICS                   *******
********************************************************************************

display "STATA Descriptive Statistics"
format cognition age grip sexmw demnf demnc %4.3f
summarize cognition age grip sexmw demnf demnc, format
summarize cognition age grip sexmw demnf demnc, detail
tabulate sexmw demgroup

display "STATA Histograms of Quantitative Variables"
histogram age,       percent discrete width(1) start(80)
histogram grip,      percent discrete width(1) start(0)
histogram cognition, percent discrete width(5) start(0)
       
display "STATA Bivariate Correlations"
pwcorr cognition age grip sexmw, sig 

    
********************************************************************************
*******                   BEGIN GENERAL LINEAR MODELS                    *******
********************************************************************************

display "STATA Empty Model Predicting Cognition"
regress cognition, level(95)

display "STATA Linear Age (0=85) Predicting Cognition"
regress cognition c.age85, level(95)

display "STATA Quadratic Age (0=85) Predicting Cognition"
regress cognition c.age85 c.age85#c.age85, level(95)
pcorr cognition c.age85##c.age85 // Get semi-partial eta-squared for each slope

display "STATA Linear Grip (0=9) Predicting Cognition"
regress cognition c.grip9, level(95)

display "STATA Quadratic Grip (0=9) Predicting Cognition"
regress cognition c.grip9 c.grip9#c.grip9, level(95)
pcorr cognition c.grip9 c.grip9#c.grip9 // Get semi-partial eta-squared for each slope

display "STATA Sex (M=0, W=1) Predicting Cognition"
regress cognition c.sexmw, level(95)
lincom _cons*1 + c.sexmw*0  // Cognition Mean for Men: B0
lincom _cons*1 + c.sexmw*1  // Cognition Mean for Women: B0+B1
lincom           c.sexmw*1  // Mean Diff: Men vs. Women: B1

display "STATA Dementia Group (Ref=None) Predicting Cognition"
regress cognition c.demnf c.demnc, level(95)
lincom _cons*1 + c.demnf*0 + c.demnc*0 // Cognition Mean for None    = B0
lincom _cons*1 + c.demnf*1 + c.demnc*0 // Cognition Mean for Future  = B0+B1
lincom _cons*1 + c.demnf*0 + c.demnc*1 // Cognition Mean for Current = B0+B2
lincom c.demnf*1  + c.demnc*0 // Mean Diff: None vs. Future    = B1
lincom c.demnf*0  + c.demnc*1 // Mean Diff: None vs. Current   = B2
lincom c.demnf*-1 + c.demnc*1 // Mean Diff: Future vs. Current = B2-B1

display "STATA Combined Model Predicting Cognition"
regress cognition c.age85 c.grip9 c.sexmw c.demnf c.demnc, level(95)
test (c.age85=0)(c.grip9=0)(c.sexmw=0)(c.demnf=0)(c.demnc=0) // F-Test DFnum=5 for Model
test (c.demnf=0)(c.demnc=0)   // F-Test DFnum=2 for Demgroup (for overall group)
test (c.age85=0)(c.sexmw=0)   // F-Test DFnum=2 for Age and Sex (for demographic vars)
lincom c.demnf*1  + c.demnc*0 // Mean Diff: None vs. Future    = B4
lincom c.demnf*0  + c.demnc*1 // Mean Diff: None vs. Current   = B5
lincom c.demnf*-1 + c.demnc*1 // Mean Diff: Future vs. Current = B5-B4
// Get semipartial eta-squared for age, grip, and sex (dem slopes not valid)
pcorr cognition c.age85 c.grip9 c.sexmw c.demnf c.demnc 

// Stata: calculate semipartial eta-squared for demgroup using SS from reduced model
display "STATA Reduced Model to Get SS for demnf and demnc (not included)"
regress cognition c.age85 c.grip9 c.sexmw, level(95)
// sr2 = (SSfull-SSreduced)/SStotal
display (18385.97930-6574.67775)/66296.5382 // sr2 for demgroup = .17815865

// Stata: calculate semipartial eta-squared for age and sex using SS from reduced model
display "STATA Reduced Model to Get SS for age85 and sexmw (not included)"
regress cognition c.grip9 c.demnf c.demnc, level(95)
// sr2 = (SSfull-SSreduced)/SStotal
display (18385.97930-15956.7691)/66296.5382 // sr2 for age and sex = .03664158


display "STATA Combined Model Predicting Cognition -- Get Std Slopes"
regress cognition c.age85 c.grip9 c.sexmw c.demnf c.demnc, beta 
// would have to recode dem contrasts to get demfc std slope

// STATA: Z-score variables for demonstration of standardized slopes
   egen cognitionz=std(cognition)
   egen agez=std(age)
   egen gripz=std(grip)
   egen sexmwz=std(sexmw)
   egen demnfz=std(demnf)
   egen demncz=std(demnc)

display "STATA Combined Model Predicting Cognition -- Z-Score Version"
regress cognitionz c.agez c.gripz c.sexmwz c.demnfz c.demncz, level(95)
lincom c.demnfz*-1 + c.demncz*1 // Mean Diff: Future vs. Current = B5-B4

// Close log
log close


